@@ -161,14 +161,14 @@ pub struct Bound<X> {
 ///
 /// Create a tick distribution from the default tick generator for the plotnum type.
 ///
-pub fn ticks_from_default<X: HasDefaultTicks>(bound: &Bound<X>) -> (TickInfo<X>, X::Fmt) {
+pub fn ticks_from_default<X: HasDefaultTicks>(bound: &Bound<X>) -> (TickInfo<X::IntoIter>, X::Fmt) {
     X::generate(bound)
 }
 
 ///
 /// Created by [`Data::build`]
 ///
-pub struct DataResult<'a, X: PlotNum + 'a, Y: PlotNum + 'a> {
+pub struct DataResult<'a, X: 'a, Y: 'a> {
     plots: Vec<Box<dyn PlotTrait<Item = (X, Y)> + 'a>>,
     canvas: render::Canvas,
     boundx: Bound<X>,
@@ -193,7 +193,7 @@ impl<'a, X: PlotNum + 'a, Y: PlotNum + 'a> DataResult<'a, X, Y> {
         title: impl Display + 'a,
         xname: impl Display + 'a,
         yname: impl Display + 'a,
-    ) -> Plotter<'a, X, Y>
+    ) -> Plotter<'a, X::IntoIter, Y::IntoIter>
     where
         X: HasDefaultTicks,
         Y: HasDefaultTicks,
@@ -207,17 +207,17 @@ impl<'a, X: PlotNum + 'a, Y: PlotNum + 'a> DataResult<'a, X, Y> {
     /// Move to final stage in pipeline collecting the title/xname/yname.
     /// Unlike [`DataResult::plot`] User must supply own tick distribution.
     ///
-    pub fn plot_with(
+    pub fn plot_with<XI: IntoIterator<Item = X>, YI: IntoIterator<Item = Y>>(
         self,
-        tickx: TickInfo<X>,
-        ticky: TickInfo<Y>,
+        tickx: TickInfo<XI>,
+        ticky: TickInfo<YI>,
         plot_fmt: impl PlotFmt<X = X, Y = Y> + 'a,
-    ) -> Plotter<'a, X, Y> {
+    ) -> Plotter<'a, XI, YI> {
         Plotter {
             plot_fmt: Box::new(plot_fmt),
             plots: self,
-            tickx,
-            ticky,
+            tickx: Some(tickx),
+            ticky: Some(ticky),
         }
     }
 }
@@ -583,14 +583,18 @@ impl<'a, X: PlotNum + 'a, Y: PlotNum + 'a> Data<'a, X, Y> {
 ///
 /// Created by [`DataResult::plot`] or [`DataResult::plot_with`]
 ///
-pub struct Plotter<'a, X: PlotNum + 'a, Y: PlotNum + 'a> {
-    plot_fmt: Box<dyn PlotFmt<X = X, Y = Y> + 'a>,
-    plots: DataResult<'a, X, Y>,
-    tickx: TickInfo<X>,
-    ticky: TickInfo<Y>,
+pub struct Plotter<'a, XI: IntoIterator, YI: IntoIterator> {
+    plot_fmt: Box<dyn PlotFmt<X = XI::Item, Y = YI::Item> + 'a>,
+    plots: DataResult<'a, XI::Item, YI::Item>,
+    tickx: Option<TickInfo<XI>>,
+    ticky: Option<TickInfo<YI>>,
 }
 
-impl<'a, X: PlotNum + 'a, Y: PlotNum + 'a> Plotter<'a, X, Y> {
+impl<'a, XI: IntoIterator, YI: IntoIterator> Plotter<'a, XI, YI>
+where
+    XI::Item: PlotNum,
+    YI::Item: PlotNum,
+{
     ///
     /// Use the plot iterators to write out the graph elements.
     /// Does not add a svg tag, or any styling elements.
@@ -661,7 +665,7 @@ pub fn disp_const<F: Fn(&mut fmt::Formatter) -> fmt::Result>(a: F) -> util::Disp
 pub fn steps<X: PlotNum + Display, I: Iterator<Item = X>>(
     bound: &Bound<X>,
     steps: I,
-) -> (TickInfo<X>, StepFmt<X>) {
+) -> (TickInfo<Vec<X>>, StepFmt<X>) {
     let ticks: Vec<_> = steps
         .skip_while(|&x| x < bound.min)
         .take_while(|&x| x <= bound.max)
